@@ -16,7 +16,7 @@ checkfail()
 # ARGUMENTS #
 #############
 
-MEDIALIBRARY_HASH=ed75aef
+MEDIALIBRARY_HASH=eed1935
 
 BUILD_ML=1
 RELEASE=0
@@ -69,7 +69,6 @@ fi
 
 VLC_BOOTSTRAP_ARGS="\
     --disable-disc \
-    --disable-sout \
     --enable-dvdread \
     --enable-dvdnav \
     --disable-dca \
@@ -108,8 +107,11 @@ VLC_BOOTSTRAP_ARGS="\
     --disable-vncclient \
     --disable-vnc \
     --enable-jpeg \
+    --enable-libplacebo \
     --enable-ad-clauses \
     --disable-srt \
+    --enable-vpx \
+    --disable-x265 \
 "
 
 ###########################
@@ -170,10 +172,9 @@ VLC_CONFIGURE_ARGS="\
     --enable-gles2 \
     --disable-goom \
     --disable-projectm \
-    --disable-sout \
+    --enable-sout \
     --enable-vorbis \
     --disable-faad \
-    --disable-x264 \
     --disable-schroedinger \
     --disable-vncclient \
     --disable-vnc \
@@ -432,7 +433,7 @@ fi
 
 if [ "${ASAN}" = 1 ];then
     VLC_CFLAGS="${VLC_CFLAGS} -O0 -fno-omit-frame-pointer -fsanitize=address"
-    VLC_CXXFLAGS="${VLC_CXXLAGS} -O0 -fno-omit-frame-pointer -fsanitize=address"
+    VLC_CXXFLAGS="${VLC_CXXFLAGS} -O0 -fno-omit-frame-pointer -fsanitize=address"
     VLC_LDFLAGS="${VLC_LDFLAGS} -ldl -fsanitize=address"
     # ugly, sorry
     if [ "${ANDROID_API}" = "9" ];then
@@ -783,7 +784,7 @@ else
     fi
 fi
 if [ "$RELEASE" = 1 ]; then
-  git checkout 0.2.x
+    git reset --hard ${MEDIALIBRARY_HASH}
 fi
 cd ${SRC_DIR}
 echo -e "\e[1m\e[36mCFLAGS:            ${CFLAGS}\e[0m"
