@@ -66,6 +66,7 @@ import org.videolan.vlc.gui.browser.ExtensionBrowser;
 import org.videolan.vlc.gui.browser.FileBrowserFragment;
 import org.videolan.vlc.gui.browser.MediaBrowserFragment;
 import org.videolan.vlc.gui.browser.NetworkBrowserFragment;
+import org.videolan.vlc.gui.dialogs.RenderersDialog;
 import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.gui.network.MRLPanelFragment;
 import org.videolan.vlc.gui.preferences.PreferencesActivity;
@@ -75,6 +76,7 @@ import org.videolan.vlc.gui.view.HackyDrawerLayout;
 import org.videolan.vlc.interfaces.Filterable;
 import org.videolan.vlc.interfaces.IRefreshable;
 import org.videolan.vlc.media.MediaUtils;
+import org.videolan.vlc.util.Constants;
 import org.videolan.vlc.util.Permissions;
 import org.videolan.vlc.util.VLCInstance;
 
@@ -89,7 +91,6 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
     private static final int ACTIVITY_RESULT_OPEN = 2;
     private static final int ACTIVITY_RESULT_SECONDARY = 3;
 
-
     private Medialibrary mMediaLibrary;
     private ExtensionsManager mExtensionsManager;
     private HackyDrawerLayout mDrawerLayout;
@@ -133,7 +134,7 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
             restoreFragmentsStack(savedInstanceState, fm);
             mCurrentFragmentId = savedInstanceState.getInt("current", mSettings.getInt("fragment_id", R.id.nav_video));
         } else {
-            if (getIntent().getBooleanExtra(StartActivity.EXTRA_UPGRADE, false)) {
+            if (getIntent().getBooleanExtra(Constants.EXTRA_UPGRADE, false)) {
             /*
              * The sliding menu is automatically opened when the user closes
              * the info dialog. If (for any reason) the dialog is not shown,
@@ -236,13 +237,19 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
         if (mMediaLibrary.isInitiated()) {
             /* Load media items from database and storage */
             if (mScanNeeded && Permissions.canReadStorage())
-                startService(new Intent(MediaParsingService.ACTION_RELOAD, null,this, MediaParsingService.class));
+                startService(new Intent(Constants.ACTION_RELOAD, null,this, MediaParsingService.class));
             else if (!currentIdIsExtension())
                 restoreCurrentList();
         }
         mNavigationView.setNavigationItemSelectedListener(this);
         if (BuildConfig.DEBUG)
             createExtensionServiceConnection();
+//        mActivityHandler.post(new Runnable() {
+//            @Override
+//            public void run() {
+//                new RenderersDialog().show(getSupportFragmentManager(), "renderers");
+//            }
+//        });
     }
 
     @Override
@@ -476,7 +483,7 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
             if(current != null && current instanceof IRefreshable)
                 ((IRefreshable) current).refresh();
             else
-                startService(new Intent(MediaParsingService.ACTION_RELOAD, null,this, MediaParsingService.class));
+                startService(new Intent(Constants.ACTION_RELOAD, null,this, MediaParsingService.class));
         }
     }
 
@@ -486,10 +493,7 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
         if (requestCode == ACTIVITY_RESULT_PREFERENCES) {
             switch (resultCode) {
                 case PreferencesActivity.RESULT_RESCAN:
-                    for (Fragment fragment : getSupportFragmentManager().getFragments())
-                        if (fragment instanceof MediaBrowserFragment)
-                            ((MediaBrowserFragment) fragment).clear();
-                    startService(new Intent(MediaParsingService.ACTION_RELOAD, null,this, MediaParsingService.class));
+                    startService(new Intent(Constants.ACTION_RELOAD, null,this, MediaParsingService.class));
                     break;
                 case PreferencesActivity.RESULT_RESTART:
                 case PreferencesActivity.RESULT_RESTART_APP:
@@ -502,6 +506,9 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
                         if (fragment instanceof VideoGridFragment)
                             ((VideoGridFragment) fragment).updateSeenMediaMarker();
                     break;
+                case PreferencesActivity.RESULT_UPDATE_ARTISTS:
+                    final Fragment fragment = getCurrentFragment();
+                    if (fragment instanceof AudioBrowserFragment) ((AudioBrowserFragment) fragment).updateArtists();
             }
         } else if (requestCode == ACTIVITY_RESULT_OPEN && resultCode == RESULT_OK){
             MediaUtils.openUri(this, data.getData());
