@@ -61,6 +61,7 @@ import org.videolan.vlc.gui.view.ContextMenuRecyclerView;
 import org.videolan.vlc.gui.view.FastScroller;
 import org.videolan.vlc.gui.view.SwipeRefreshLayout;
 import org.videolan.vlc.util.AndroidDevices;
+import org.videolan.vlc.util.Constants;
 import org.videolan.vlc.util.FileUtils;
 import org.videolan.vlc.util.Util;
 import org.videolan.vlc.util.WeakHandler;
@@ -215,7 +216,7 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         if (pos != MODE_SONG && pos != MODE_PLAYLIST)
             menu.findItem(R.id.audio_list_browser_delete).setVisible(false);
         else {
-            MenuItem item = menu.findItem(R.id.audio_list_browser_delete);
+            final MenuItem item = menu.findItem(R.id.audio_list_browser_delete);
             AudioBrowserAdapter adapter = pos == MODE_SONG ? mSongsAdapter : mPlaylistAdapter;
             MediaLibraryItem mediaItem = adapter.getItem(position);
             if (pos == MODE_PLAYLIST )
@@ -239,43 +240,50 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         final MediaLibraryItem mediaItem = adapter.getItem(position);
 
         if (id == R.id.audio_list_browser_delete) {
-            final MediaLibraryItem mediaLibraryItem = adapter.getItem(position);
             final MediaLibraryItem previous = position > 0 ? adapter.getItem(position-1) : null;
             final MediaLibraryItem next = position < adapter.getItemCount()-1 ? adapter.getItem(position+1) : null;
-            String message;
-            Runnable action;
+            final String message;
+            final Runnable action;
+            final Runnable cancel;
             final MediaLibraryItem separator = previous != null && previous.getItemType() == MediaLibraryItem.TYPE_DUMMY &&
                     (next == null || next.getItemType() == MediaLibraryItem.TYPE_DUMMY) ? previous : null;
-            adapter.remove(mediaLibraryItem);
-            if (separator != null)
-                adapter.remove(separator);
+            if (separator != null) adapter.remove(separator, mediaItem);
+            else adapter.remove(mediaItem);
 
             if (mode == MODE_PLAYLIST) {
+                cancel = null;
                 message = getString(R.string.playlist_deleted);
                 action = new Runnable() {
                     @Override
                     public void run() {
-                        deletePlaylist((Playlist) mediaLibraryItem);
+                        deletePlaylist((Playlist) mediaItem);
                     }
                 };
             } else if (mode == MODE_SONG) {
                 message = getString(R.string.file_deleted);
+                cancel = new Runnable() {
+                    @Override
+                    public void run() {
+                        if (separator != null) adapter.addItems(separator, mediaItem);
+                        else adapter.addItems(mediaItem);
+                    }
+                };
                 action = new Runnable() {
                     @Override
                     public void run() {
-                        deleteMedia(mediaLibraryItem, true);
+                        deleteMedia(mediaItem, true, cancel);
                     }
                 };
-            } else
-                return false;
-            UiTools.snackerWithCancel(getView(), message, action, new Runnable() {
-                @Override
-                public void run() {
-                    if (separator != null)
-                        adapter.addItem(position-1, separator);
-                    adapter.addItem(position, mediaLibraryItem);
-                }
-            });
+                if (!checkWritePermission((MediaWrapper) mediaItem, new Runnable() {
+                    @Override
+                    public void run() {
+                        final View v = getView();
+                        if (v != null) UiTools.snackerWithCancel(getView(), message, action, cancel);
+                    }
+                })) return false;
+            } else return false;
+            final View v = getView();
+            if (v != null) UiTools.snackerWithCancel(getView(), message, action, cancel);
             return true;
         }
 
@@ -307,7 +315,7 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         if (useAllItems) {
             if (mSongsAdapter.getItemCount() <= position)
                 return false;
-            final ArrayList<MediaLibraryItem> mediaList = new ArrayList<>();
+            final List<MediaLibraryItem> mediaList = new ArrayList<>();
             startPosition = mSongsAdapter.getListWithPosition(mediaList, position);
             medias = Arrays.copyOf(mediaList.toArray(), mediaList.size(), MediaWrapper[].class);
         } else {
@@ -361,7 +369,7 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
     @Override
     public void onRefresh() {
         mActivity.closeSearchView();
-        VLCApplication.getAppContext().startService(new Intent(MediaParsingService.ACTION_RELOAD, null, VLCApplication.getAppContext(), MediaParsingService.class));
+        VLCApplication.getAppContext().startService(new Intent(Constants.ACTION_RELOAD, null, VLCApplication.getAppContext(), MediaParsingService.class));
     }
 
     @Override
@@ -445,6 +453,7 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
 
     @Override
     public void onClick(View v, int position, MediaLibraryItem item) {
+        if (item == null) return;
         if (mActionMode != null) {
             super.onClick(v, position, item);
             return;
@@ -579,17 +588,12 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         updatePlaylists();
     }
 
-    private void updateArtists() {
+    public void updateArtists() {
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
-                final ArrayList<MediaLibraryItem> artists = Util.arrayToMediaArrayList(mMediaLibrary.getArtists());
-                VLCApplication.runOnMainThread(new Runnable() {
-                    @Override
-                    public void run() {
-                        mArtistsAdapter.update(artists);
-                    }
-                });
+                final List<MediaLibraryItem> artists = Util.arrayToMediaArrayList(mMediaLibrary.getArtists(VLCApplication.getSettings().getBoolean(Constants.KEY_ARTISTS_SHOW_ALL, false)));
+                mArtistsAdapter.update(artists);
             }
         });
     }
@@ -598,13 +602,8 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
-                final ArrayList<MediaLibraryItem> albums = Util.arrayToMediaArrayList(mMediaLibrary.getAlbums());
-                VLCApplication.runOnMainThread(new Runnable() {
-                    @Override
-                    public void run() {
-                        mAlbumsAdapter.update(albums);
-                    }
-                });
+                final List<MediaLibraryItem> albums = Util.arrayToMediaArrayList(mMediaLibrary.getAlbums());
+                mAlbumsAdapter.update(albums);
             }
         });
     }
@@ -613,13 +612,8 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
-                final ArrayList<MediaLibraryItem> media = Util.arrayToMediaArrayList(mMediaLibrary.getAudio());
-                VLCApplication.runOnMainThread(new Runnable() {
-                    @Override
-                    public void run() {
-                        mSongsAdapter.update(media);
-                    }
-                });
+                final List<MediaLibraryItem> media = Util.arrayToMediaArrayList(mMediaLibrary.getAudio());
+                mSongsAdapter.update(media);
             }
         });
     }
@@ -628,13 +622,8 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
-                final ArrayList<MediaLibraryItem> genres = Util.arrayToMediaArrayList(mMediaLibrary.getGenres());
-                VLCApplication.runOnMainThread(new Runnable() {
-                    @Override
-                    public void run() {
-                        mGenresAdapter.update(genres);
-                    }
-                });
+                final List<MediaLibraryItem> genres = Util.arrayToMediaArrayList(mMediaLibrary.getGenres());
+                mGenresAdapter.update(genres);
             }
         });
     }
@@ -643,13 +632,8 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
-                final ArrayList<MediaLibraryItem> playlists = Util.arrayToMediaArrayList(mMediaLibrary.getPlaylists());
-                VLCApplication.runOnMainThread(new Runnable() {
-                    @Override
-                    public void run() {
-                        mPlaylistAdapter.update(playlists);
-                    }
-                });
+                final List<MediaLibraryItem> playlists = Util.arrayToMediaArrayList(mMediaLibrary.getPlaylists());
+                mPlaylistAdapter.update(playlists);
             }
         });
     }
