@@ -73,7 +73,6 @@ import org.videolan.vlc.interfaces.IRefreshable;
 import org.videolan.vlc.media.MediaDatabase;
 import org.videolan.vlc.media.MediaUtils;
 import org.videolan.vlc.util.AndroidDevices;
-import org.videolan.vlc.util.FileUtils;
 import org.videolan.vlc.util.Strings;
 import org.videolan.vlc.util.Util;
 import org.videolan.vlc.util.VLCInstance;
@@ -81,6 +80,7 @@ import org.videolan.vlc.util.WeakHandler;
 
 import java.util.ArrayList;
 import java.util.LinkedList;
+import java.util.List;
 
 
 public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAdapter> implements IRefreshable, MediaBrowser.EventListener, SwipeRefreshLayout.OnRefreshListener, View.OnClickListener, Filterable, IEventsHandler {
@@ -93,7 +93,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
     public static final String KEY_POSITION = "key_list";
 
     public volatile boolean refreshing = false;
-    private ArrayList<MediaLibraryItem> refreshList;
+    private List<MediaLibraryItem> refreshList;
 
     protected BrowserFragmentHandler mHandler;
     protected MediaBrowser mMediaBrowser;
@@ -108,7 +108,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
     protected boolean goBack = false;
     private final boolean mShowHiddenFiles;
 
-    private SimpleArrayMap<MediaLibraryItem, ArrayList<MediaLibraryItem>> mFoldersContentLists;
+    private SimpleArrayMap<MediaLibraryItem, List<MediaLibraryItem>> mFoldersContentLists;
     public int mCurrentParsedPosition = 0;
 
     protected abstract Fragment createFragment();
@@ -141,7 +141,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
             bundle = getArguments();
         if (bundle != null) {
             if (VLCApplication.hasData(KEY_CONTENT_LIST))
-                mFoldersContentLists = (SimpleArrayMap<MediaLibraryItem, ArrayList<MediaLibraryItem>>) VLCApplication.getData(KEY_CONTENT_LIST);
+                mFoldersContentLists = (SimpleArrayMap<MediaLibraryItem, List<MediaLibraryItem>>) VLCApplication.getData(KEY_CONTENT_LIST);
             mCurrentMedia = bundle.getParcelable(KEY_MEDIA);
             if (mCurrentMedia != null)
                 mMrl = mCurrentMedia.getLocation();
@@ -197,11 +197,11 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
 
         VLCApplication.storeData(KEY_CONTENT_LIST+mMrl, mFoldersContentLists);
         @SuppressWarnings("unchecked")
-        final SimpleArrayMap<MediaLibraryItem, ArrayList<MediaLibraryItem>> content = (SimpleArrayMap<MediaLibraryItem, ArrayList<MediaLibraryItem>>) VLCApplication.getData(KEY_CONTENT_LIST + mMrl);
+        final SimpleArrayMap<MediaLibraryItem, List<MediaLibraryItem>> content = (SimpleArrayMap<MediaLibraryItem, List<MediaLibraryItem>>) VLCApplication.getData(KEY_CONTENT_LIST + mMrl);
         if (content != null)
             mFoldersContentLists = content;
         @SuppressWarnings("unchecked")
-        final ArrayList<MediaLibraryItem> mediaList = (ArrayList<MediaLibraryItem>) VLCApplication.getData(KEY_MEDIA_LIST + mMrl);
+        final List<MediaLibraryItem> mediaList = (List<MediaLibraryItem>) VLCApplication.getData(KEY_MEDIA_LIST + mMrl);
         if (!Util.isListEmpty(mediaList))
             mAdapter.update(mediaList);
         else
@@ -295,7 +295,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
         final Bundle args = new Bundle();
         VLCApplication.storeData(KEY_MEDIA_LIST+mMrl, mAdapter.getAll());
         VLCApplication.storeData(KEY_CONTENT_LIST+ mMrl, mFoldersContentLists);
-        final ArrayList<MediaLibraryItem> list = mFoldersContentLists.get(media);
+        final List<MediaLibraryItem> list = mFoldersContentLists.get(media);
         if (!Util.isListEmpty(list) && !(this instanceof StorageBrowserFragment))
             VLCApplication.storeData(KEY_MEDIA_LIST+ media.getLocation(), list);
         args.putParcelable(KEY_MEDIA, media);
@@ -317,32 +317,13 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
             refreshList.add(mediaWrapper);
             return;
         }
-        final boolean wasEmpty = mAdapter.isEmpty();
         final MediaWrapper mediaWrapper = getMediaWrapper(new MediaWrapper(media));
-        VLCApplication.runOnMainThread(new Runnable() {
-            @Override
-            public void run() {
-                publishMedia(mediaWrapper, wasEmpty);
-            }
-        });
-    }
-
-    private void publishMedia(MediaWrapper mw, boolean wasEmpty) {
-        mAdapter.addItem(mw, false);
-        if (wasEmpty) {
-            updateEmptyView();
-            mHandler.sendEmptyMessage(BrowserFragmentHandler.MSG_HIDE_LOADING);
-        }
+        mAdapter.addItem(mediaWrapper, false);
     }
 
     @Override
     public void onMediaRemoved(int index, final Media media) {
-        VLCApplication.runOnMainThread(new Runnable() {
-            @Override
-            public void run() {
-                mAdapter.removeItem(media.getUri().toString());
-            }
-        });
+        mAdapter.removeItem(media.getUri().toString());
     }
 
     @Override
@@ -512,7 +493,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
         final MediaWrapper mw = (MediaWrapper) mAdapter.getItem(position);
         if (mw == null) return;
         final int type = mw.getType();
-        boolean canWrite = this instanceof FileBrowserFragment && FileUtils.canWrite(mw.getUri().getPath());
+        boolean canWrite = this instanceof FileBrowserFragment;
         if (type == MediaWrapper.TYPE_DIR) {
             final boolean isEmpty = Util.isListEmpty(mFoldersContentLists.get(mw));
 //                if (canWrite) {
@@ -555,7 +536,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
         int id = item.getItemId();
         if (! (mAdapter.getItem(position) instanceof MediaWrapper))
             return super.onContextItemSelected(item);
-        Uri uri = ((MediaWrapper) mAdapter.getItem(position)).getUri();
+        final Uri uri = ((MediaWrapper) mAdapter.getItem(position)).getUri();
         MediaWrapper mwFromMl = "file".equals(uri.getScheme()) ? mMediaLibrary.getMedia(uri) : null;
         final MediaWrapper mw = mwFromMl != null ? mwFromMl : (MediaWrapper) mAdapter.getItem(position);
         switch (id){
@@ -569,20 +550,12 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
                 return true;
             }
             case R.id.directory_view_delete:
-                mAdapter.removeItem(position);
-                final Runnable cancel = new Runnable() {
+                if (checkWritePermission(mw, new Runnable() {
                     @Override
                     public void run() {
-                        mAdapter.addItem(mw, true, position);
+                        removeMedia(mw);
                     }
-                };
-                final View v = getView();
-                if (v != null) UiTools.snackerWithCancel(v, getString(R.string.file_deleted), new Runnable() {
-                    @Override
-                    public void run() {
-                        deleteMedia(mw, false, cancel);
-                    }
-                }, cancel);
+                })) removeMedia(mw);
                 return true;
             case  R.id.directory_view_info:
                 showMediaInfo(mw);
@@ -594,7 +567,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
                 }
                 return true;
             case R.id.directory_view_play_folder:
-                ArrayList<MediaWrapper> newMediaList = new ArrayList<>();
+                List<MediaWrapper> newMediaList = new ArrayList<>();
                 for (MediaLibraryItem mediaItem : mFoldersContentLists.get(mAdapter.get(position))){
                     if (((MediaWrapper)mediaItem).getType() == MediaWrapper.TYPE_AUDIO || (AndroidUtil.isHoneycombOrLater && ((MediaWrapper)mediaItem).getType() == MediaWrapper.TYPE_VIDEO))
                         newMediaList.add((MediaWrapper)mediaItem);
@@ -627,6 +600,23 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
         return false;
     }
 
+    private void removeMedia(final MediaWrapper mw) {
+        mAdapter.removeItem(mw);
+        final Runnable cancel = new Runnable() {
+            @Override
+            public void run() {
+                mAdapter.addItem(mw, true);
+            }
+        };
+        final View v = getView();
+        if (v != null) UiTools.snackerWithCancel(v, getString(R.string.file_deleted), new Runnable() {
+            @Override
+            public void run() {
+                deleteMedia(mw, false, cancel);
+            }
+        }, cancel);
+    }
+
     private void showMediaInfo(MediaWrapper mw) {
         Intent i = new Intent(getActivity(), InfoActivity.class);
         i.putExtra(InfoActivity.TAG_ITEM, mw);
@@ -649,7 +639,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
         MediaUtils.openList(getActivity(), mediaLocations, positionInPlaylist);
     }
 
-    ArrayList<MediaLibraryItem> currentMediaList = new ArrayList<>();
+    List<MediaLibraryItem> currentMediaList = new ArrayList<>();
     protected void parseSubDirectories() {
         synchronized (currentMediaList) {
             currentMediaList = new ArrayList<>(mAdapter.getAll());
@@ -690,8 +680,8 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
     }
 
     private MediaBrowser.EventListener mFoldersBrowserListener = new MediaBrowser.EventListener(){
-        ArrayList<MediaWrapper> directories = new ArrayList<>();
-        ArrayList<MediaWrapper> files = new ArrayList<>();
+        List<MediaWrapper> directories = new ArrayList<>();
+        List<MediaWrapper> files = new ArrayList<>();
 
         @Override
         public void onMediaAdded(int index, final Media media) {
@@ -823,7 +813,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
             return false;
         }
         boolean single = this instanceof FileBrowserFragment && count == 1;
-        final ArrayList<MediaWrapper> selection = single ? mAdapter.getSelection() : null;
+        final List<MediaWrapper> selection = single ? mAdapter.getSelection() : null;
         int type = !Util.isListEmpty(selection) ? selection.get(0).getType() : -1;
         menu.findItem(R.id.action_mode_file_info).setVisible(single && (type == MediaWrapper.TYPE_AUDIO || type == MediaWrapper.TYPE_VIDEO));
         menu.findItem(R.id.action_mode_file_append).setVisible(mService.hasMedia());
@@ -832,7 +822,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
 
     @Override
     public boolean onActionItemClicked(ActionMode mode, MenuItem item) {
-        ArrayList<MediaWrapper> list = mAdapter.getSelection();
+        List<MediaWrapper> list = mAdapter.getSelection();
         if (!list.isEmpty()) {
             switch (item.getItemId()) {
                 case R.id.action_mode_file_play:
