@@ -45,8 +45,6 @@ import android.view.MenuItem;
 import android.view.View;
 import android.view.ViewGroup;
 import android.widget.Filter;
-import android.widget.LinearLayout;
-import android.widget.TextView;
 
 import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.medialibrary.Medialibrary;
@@ -69,7 +67,7 @@ import org.videolan.vlc.interfaces.Filterable;
 import org.videolan.vlc.interfaces.IEventsHandler;
 import org.videolan.vlc.media.MediaGroup;
 import org.videolan.vlc.media.MediaUtils;
-import org.videolan.vlc.util.FileUtils;
+import org.videolan.vlc.util.Constants;
 import org.videolan.vlc.util.Util;
 
 import java.util.ArrayList;
@@ -77,15 +75,13 @@ import java.util.List;
 
 public class VideoGridFragment extends SortableFragment<VideoListAdapter> implements MediaUpdatedCb, SwipeRefreshLayout.OnRefreshListener, MediaAddedCb, Filterable, IEventsHandler {
 
-    public final static String TAG = "VLC/VideoListFragment";
+    private final static String TAG = "VLC/VideoListFragment";
 
-    public final static String KEY_GROUP = "key_group";
+    private final static String KEY_GROUP = "key_group";
 
-    protected LinearLayout mLayoutFlipperLoading;
-    protected AutoFitRecyclerView mGridView;
-    protected TextView mTextViewNomedia;
-    protected View mViewNomedia;
-    protected String mGroup;
+    private AutoFitRecyclerView mGridView;
+    private View mViewNomedia;
+    private String mGroup;
     private View mSearchButtonView;
     private DividerItemDecoration mDividerItemDecoration;
 
@@ -116,7 +112,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
     public boolean onOptionsItemSelected(MenuItem item) {
         switch (item.getItemId()) {
             case R.id.ml_menu_last_playlist:
-                getActivity().sendBroadcast(new Intent(PlaybackService.ACTION_REMOTE_LAST_VIDEO_PLAYLIST));
+                getActivity().sendBroadcast(new Intent(Constants.ACTION_REMOTE_LAST_VIDEO_PLAYLIST));
                 return true;
             default:
                 return super.onOptionsItemSelected(item);
@@ -131,8 +127,6 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
     @Override
     public void onViewCreated(View v, @Nullable Bundle savedInstanceState) {
         super.onViewCreated(v, savedInstanceState);
-        mLayoutFlipperLoading = v.findViewById(R.id.layout_flipper_loading);
-        mTextViewNomedia = v.findViewById(R.id.textview_nomedia);
         mViewNomedia = v.findViewById(android.R.id.empty);
         mGridView = v.findViewById(android.R.id.list);
         mSwipeRefreshLayout = v.findViewById(R.id.swipeLayout);
@@ -147,7 +141,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
         if (mAdapter.isListMode())
             mGridView.addItemDecoration(mDividerItemDecoration);
         if (savedInstanceState != null) {
-            final ArrayList<MediaWrapper> list = (ArrayList<MediaWrapper>) VLCApplication.getData("list"+getTitle());
+            final List<MediaWrapper> list = (List<MediaWrapper>) VLCApplication.getData("list"+getTitle());
             if (!Util.isListEmpty(list))
                 mAdapter.update(list);
         }
@@ -253,8 +247,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
     }
 
     protected boolean handleContextItemSelected(MenuItem menu, final int position) {
-        if (position >= mAdapter.getItemCount())
-            return false;
+        if (position >= mAdapter.getItemCount()) return false;
         final MediaWrapper media = mAdapter.getItem(position);
         if (media == null)
             return false;
@@ -266,7 +259,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
                 playAudio(media);
                 return true;
             case R.id.video_list_play_all:
-                ArrayList<MediaWrapper> playList = new ArrayList<>();
+                List<MediaWrapper> playList = new ArrayList<>();
                 MediaUtils.openList(getActivity(), playList, mAdapter.getListWithPosition(playList, position));
                 return true;
             case R.id.video_list_info:
@@ -292,13 +285,19 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
     }
 
     private void removeVideo(final MediaWrapper media) {
+        if (!checkWritePermission(media, new Runnable() {
+            @Override
+            public void run() {
+                removeVideo(media);
+            }
+        })) return;
         final int position = mAdapter.remove(media);
         final View view = getView();
         if (position != -1 && view != null) {
             final Runnable revert = new Runnable() {
                 @Override
                 public void run() {
-                    mAdapter.add(media, position);
+                    mAdapter.add(media);
                 }
             };
             UiTools.snackerWithCancel(view, getString(R.string.file_deleted), new Runnable() {
@@ -312,13 +311,11 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
 
     @Override
     public void onCreateContextMenu(ContextMenu menu, View v, ContextMenu.ContextMenuInfo menuInfo) {
-        if (menuInfo == null)
-            return;
+        if (menuInfo == null) return;
         // Do not show the menu of media group.
         final ContextMenuRecyclerView.RecyclerContextMenuInfo info = (ContextMenuRecyclerView.RecyclerContextMenuInfo)menuInfo;
         final MediaWrapper media = mAdapter.getItem(info.position);
-        if (media == null)
-            return;
+        if (media == null) return;
         final MenuInflater inflater = getActivity().getMenuInflater();
         inflater.inflate(media instanceof MediaGroup ? R.menu.video_group_contextual : R.menu.video_list, menu);
         if (media instanceof MediaGroup) {
@@ -326,14 +323,11 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
                 menu.findItem(R.id.video_list_append).setVisible(false);
                 menu.findItem(R.id.video_group_play).setVisible(false);
             }
-        } else
-            setContextMenuItems(menu, media);
+        } else setContextMenuItems(menu, media);
     }
 
     private void setContextMenuItems(Menu menu, MediaWrapper mediaWrapper) {
         menu.findItem(R.id.video_list_play_from_start).setVisible(mediaWrapper.getTime() > 0);
-        final boolean canWrite = FileUtils.canWrite(mediaWrapper.getLocation());
-        menu.findItem(R.id.video_list_delete).setVisible(canWrite);
         if (!AndroidUtil.isHoneycombOrLater) {
             menu.findItem(R.id.video_list_play_all).setVisible(false);
             menu.findItem(R.id.video_list_append).setVisible(false);
@@ -342,7 +336,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
 
     @Override
     public void onFabPlayClick(View view) {
-        ArrayList<MediaWrapper> playList = new ArrayList<>();
+        List<MediaWrapper> playList = new ArrayList<>();
         MediaUtils.openList(getActivity(), playList, mAdapter.getListWithPosition(playList, 0));
     }
 
@@ -364,7 +358,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
             @Override
             public void run() {
                 final MediaWrapper[] itemList = mMediaLibrary.getVideos();
-                final ArrayList<MediaWrapper> displayList = new ArrayList<>();
+                final List<MediaWrapper> displayList = new ArrayList<>();
                 if (mGroup != null) {
                     for (MediaWrapper item : itemList) {
                         String title = item.getTitle().substring(item.getTitle().toLowerCase().startsWith("the") ? 4 : 0);
@@ -375,12 +369,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
                     for (MediaGroup item : MediaGroup.group(itemList))
                         displayList.add(item.getMedia());
                 }
-                VLCApplication.runOnMainThread(new Runnable() {
-                    @Override
-                    public void run() {
-                        mAdapter.update(displayList);
-                    }
-                });
+                mAdapter.update(displayList);
                 mHandler.sendEmptyMessage(UNSET_REFRESHING);
             }
         });
@@ -396,7 +385,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
 
     @Override
     public void onRefresh() {
-        getActivity().startService(new Intent(MediaParsingService.ACTION_RELOAD, null, getActivity(), MediaParsingService.class));
+        getActivity().startService(new Intent(Constants.ACTION_RELOAD, null, getActivity(), MediaParsingService.class));
     }
 
     @Override
@@ -503,7 +492,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
     public void onDestroyActionMode(ActionMode mode) {
         mActionMode = null;
         setFabPlayVisibility(true);
-        final ArrayList<MediaWrapper> items = mAdapter.getAll();
+        final List<MediaWrapper> items = mAdapter.getAll();
         for (int i = 0; i < items.size(); ++i) {
             MediaWrapper mw = items.get(i);
             if (mw.hasStateFlags(MediaLibraryItem.FLAG_SELECTED)) {
@@ -556,7 +545,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
             media.removeFlags(MediaWrapper.MEDIA_FORCE_AUDIO);
             final SharedPreferences settings = PreferenceManager.getDefaultSharedPreferences(VLCApplication.getAppContext());
             if (settings.getBoolean("force_play_all", false)) {
-                final ArrayList<MediaWrapper> playList = new ArrayList<>();
+                final List<MediaWrapper> playList = new ArrayList<>();
                 MediaUtils.openList(activity, playList, mAdapter.getListWithPosition(playList, position));
             } else {
                 playVideo(media, false);
